==> apache-iotdb-0.12.3-source-release.zip: apache-iotdb-0.12.3/docs/zh/Community/Feedback.md <==
<!--

    Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at
    
        http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.

-->

## 联系我们

作为Apache项目，我们使用邮件列表、JIRA和Github的issue模块来获取用户反馈。

* 邮件列表: dev@iotdb.apache.org.

    * 该列表同时用于用户反馈和开发者交流.
    * 订阅方法：用想接收邮件的邮箱向 dev-subscribe@iotdb.apache.org 发一封邮件，主题内容不限，收到回复后，
    再次向确认地址发一封确认邮件（确认地址比较长，推荐qq邮箱）。

* JIRA issue: https://issues.apache.org/jira/projects/IOTDB/issues

* Github issue: https://github.com/apache/iotdb/issues

* Twitter: https://twitter.com/apacheiotdb

* 对中文用户，欢迎加入QQ群: 659990460.
  
* 我们非常期待您分享您使用IoTDB的经验: [调研问卷](https://github.com/apache/iotdb/issues/748)

* 对中文用户，欢迎关注微信公众号，IoTDB漫游指南

* 对中文用户，我们提供了钉钉群，可以搜索群名称加入：Apache IoTDB交流1群

IoTDB社区会不定期举办Meetup，相关信息会在邮件列表和[研讨会议和报告列表](https://iotdb.apache.org/Community/Materials.html) 页面找到。

==> apache-iotdb-0.13.0-source-release.zip: apache-iotdb-0.13.0/docs/zh/Community/Feedback.md <==
<!--

    Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at
    
        http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.

-->

## 联系我们

作为 Apache 项目，我们使用邮件列表、JIRA 和 Github 的 issue 模块来获取用户反馈。

* 邮件列表：dev@iotdb.apache.org.

    * 该列表同时用于用户反馈和开发者交流。
    * 订阅方法：用想接收邮件的邮箱向 dev-subscribe@iotdb.apache.org 发一封邮件，主题内容不限，收到回复后，
    再次向确认地址发一封确认邮件（确认地址比较长，推荐 qq 邮箱）。

* JIRA issue: https://issues.apache.org/jira/projects/IOTDB/issues

* Github issue: https://github.com/apache/iotdb/issues

* Twitter: https://twitter.com/apacheiotdb

* 对中文用户，欢迎加入 QQ 群：659990460.
  
* 我们非常期待您分享您使用 IoTDB 的经验：[调研问卷](https://github.com/apache/iotdb/issues/748)

* 对中文用户，欢迎关注微信公众号，IoTDB 漫游指南

* 对中文用户，我们提供了钉钉群，可以搜索群名称加入：Apache IoTDB 交流 1 群

IoTDB 社区会不定期举办 Meetup，相关信息会在邮件列表和 [研讨会议和报告列表](https://iotdb.apache.org/Community/Materials.html) 页面找到。
